﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace ganme1
{
    public enum MoveType
    {
        Left,
        Right
    }

    /// <summary>
    /// 底部小木板类
    /// </summary>
    public class Bottom : Bullet
    {
        private int width;//长度
        private int x;  //最左端的横坐标长度
        private int previousX; //储存前一个位置
        private bool isRun; //判断小球是否在运动中
        

        public bool IsRun
        {
            get { return isRun; }
            set { isRun = value; }
        }

        public int X
        {
            get { return x; }
            set { x = value; }
        }

        public int Width
        {
            get { return width; }
            set { width = value; }
        }

        public Bottom()
        {
            width = 6;
            x = From.Width / 2 - width / 2;
            previousX = x;
        }

        /// <summary>
        /// 绘制自身
        /// </summary>
        public void Draw()
        {
            Console.ForegroundColor = ConsoleColor.Red;
            lock (From.Map)
            {
                for (int i = x; i < x + width; i++)
                {
                    Console.SetCursorPosition(From.Left + 2 + 2 * i, From.Top + 1 + From.Height - 1);
                    Console.Write("▓");
                    From.Map[i, From.Height - 1] = 3;
                }
            }
        }

        /// <summary>
        /// 处理键盘输入
        /// </summary>
        public bool HandleInput()
        {
            ConsoleKeyInfo key;
            while (true)
            {
                key = Console.ReadKey(true);
                HandleInput(key);
            }
        }

        /// <summary>
        /// 处理开局键盘输入True表示已经在游戏状态，Flase表示即将发球
        /// </summary>
        /// <returns></returns>
        public bool StartInput()
        {
            ConsoleKeyInfo key;
            while (!Game.IsMortality1 && !Game.IsWin)
            {
                key = Console.ReadKey(true);
                if (!HandleInput(key))
                {
                    return false;
                }
            }
            return true;
        }

        public bool HandleInput(ConsoleKeyInfo key)
        {
            bool state = true;
            switch (key.Key)
            {
                case ConsoleKey.A:
                    x = x > 1 ? x -= 2 : x;
                    Move(MoveType.Left);
                    break;

                case ConsoleKey.D:
                    x = x < From.Width - width - 1 ? x += 2 : x;
                    Move(MoveType.Right);
                    break;

                case ConsoleKey.W:
                    if (!isRun)
                    {
                        state = false;
                    
                    isRun = true;
                        }
                    break;
                default:
                    break;
            }
            return state;
        }
        /// <summary>
        /// 移动
        /// </summary>
        /// <param name="type"></param>
        public void Move(MoveType type)
        {
            if (type == MoveType.Left)
            {
                Clear();
                Draw();
            }
            if (type == MoveType.Right)
            {
                Clear();
                Draw();
            }
        }

        public override void Clear()
        {
            lock (From.Map)
            {
                for (int i = 0; i < From.Width; i++)
                {
                    Console.SetCursorPosition(From.Left + 2 + 2 * i, From.Top + 1 + From.Height - 1);
                    Console.Write("  ");
                    From.Map[i, From.Height - 1] = 0;
                }
            }
        }
    }
}
